@@ -1,9 +1,9 @@
 from django.core.cache import cache
 from django.urls import reverse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from wagtail.contrib.modeladmin.helpers import PageButtonHelper
 
-from wagtail.core import hooks
+from wagtail import hooks
 
 from wagtail.contrib.modeladmin.options import (
     ModelAdmin,
@@ -11,7 +11,7 @@ from wagtail.contrib.modeladmin.options import (
     modeladmin_register,
 )
 
-from .models import GridCategory, GridIndexPage
+from .models import GridCategory, GridIndexPage, GridIndexPageAbstract, GridItem
 from .settings import get_clear_cache
 
 
@@ -81,5 +81,5 @@ def clear_page_cache(request, page):
     fragments specifics.
     """
 
-    if get_clear_cache():
+    if get_clear_cache() and isinstance(page, (GridItem, GridIndexPageAbstract)):
         cache.clear()
